@@ -3,9 +3,34 @@ package Beekeeper::Service::LogTail::Worker;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.01';
+
+=head1 NAME
+
+Beekeeper::Service::LogTail::Worker - Buffer log entries
+
+=head1 VERSION
+
+Version 0.01
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+By default all workers use a C<Beekeeper::Logger> logger which logs errors and
+warnings both to files and to a topic C</topic/log> on the message bus.
+
+This worker keeps an in memory buffer of every log entry sent to that topic in
+every broker in a logical message bus.
+
+=head1 METHODS
+
+=head3 tail ( %filters )
+
+Returns all buffered entries that match the filter criteria.
+
+=cut
 
-use AnyEvent::Impl::Perl;
 use Beekeeper::Worker ':log';
 use base 'Beekeeper::Worker';
 
@@ -18,9 +43,9 @@ my @Log_buffer;
 sub authorize_request {
     my ($self, $req) = @_;
 
-    return unless $self->__has_authorization_token('BKPR_ADMIN');
+    return unless $req->has_auth_tokens('BKPR_ADMIN');
 
-    return BKPR_REQUEST_AUTHORIZED;
+    return REQUEST_AUTHORIZED;
 }
 
 sub on_startup {
@@ -30,7 +55,7 @@ sub on_startup {
 
     $self->_connect_to_all_brokers;
 
-    $self->accept_remote_calls(
+    $self->accept_jobs(
         '_bkpr.logtail.tail' => 'tail',
     );
 }
@@ -40,13 +65,13 @@ sub _connect_to_all_brokers {
     weaken($self);
 
     my $own_bus = $self->{_BUS};
-    my $group_config = Beekeeper::Config->get_bus_group_config( bus_id => $own_bus->bus_id );
+    my $cluster_config = Beekeeper::Config->get_cluster_config( bus_id => $own_bus->bus_id );
 
-    $self->{_BUS_GROUP} = [];
+    $self->{_CLUSTER} = [];
 
-    foreach my $config (@$group_config) {
+    foreach my $config (@$cluster_config) {
 
-        my $bus_id = $config->{'bus_id'};
+        my $bus_id = $config->{'bus-id'};
 
         if ($bus_id eq $own_bus->bus_id) {
             # Already connected to our own bus
@@ -54,7 +79,7 @@ sub _connect_to_all_brokers {
             next;
         }
 
-        my $bus; $bus = Beekeeper::MQTT->new( 
+        my $bus; $bus = Beekeeper::Bus::STOMP->new( 
             %$config,
             bus_id     => $bus_id,
             timeout    => 300,
@@ -74,7 +99,7 @@ sub _connect_to_all_brokers {
             },
         );
 
-        push @{$self->{_BUS_GROUP}}, $bus;
+        push @{$self->{_CLUSTER}}, $bus;
 
         $bus->connect;
     }
@@ -84,11 +109,11 @@ sub _collect_log {
     my ($self, $bus) = @_;
     weaken($self);
 
-    # Default logger logs to topic log/$level/$service
+    # Default logger logs to topics /topic/log.$level.$service
 
     $bus->subscribe(
-        topic      => "log/#",
-        on_publish => sub {
+        destination    => "/topic/log.#",
+        on_receive_msg => sub {
             my ($body_ref, $msg_headers) = @_;
 
             my $req = decode_json($$body_ref);
@@ -107,10 +132,10 @@ sub _collect_log {
 sub on_shutdown {
     my ($self, %args) = @_;
 
-     foreach my $bus (@{$self->{_BUS_GROUP}}) {
+     foreach my $bus (@{$self->{_CLUSTER}}) {
 
         next unless ($bus->{is_connected});
-        $bus->disconnect;
+        $bus->disconnect( blocking => 1 );
     }
 }
 
@@ -165,43 +190,15 @@ sub tail {
 
 1;
 
-__END__
-
-=pod
-
 =encoding utf8
 
-=head1 NAME
-
-Beekeeper::Service::LogTail::Worker - Buffer log entries
-
-=head1 VERSION
-
-Version 0.03
-
-=head1 SYNOPSIS
-
-=head1 DESCRIPTION
-
-By default all workers use a C<Beekeeper::Logger> logger which logs errors and
-warnings both to files and to a topic C</topic/log> on the message bus.
-
-This worker keeps an in memory buffer of every log entry sent to that topic in
-every broker in a logical message bus.
-
-=head1 METHODS
-
-=head3 tail ( %filters )
-
-Returns all buffered entries that match the filter criteria.
-
 =head1 AUTHOR
 
 José Micó, C<jose.mico@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015-2021 José Micó.
+Copyright 2015 José Micó.
 
 This is free software; you can redistribute it and/or modify it under the same 
 terms as the Perl 5 programming language itself.
