@@ -11,11 +11,12 @@ my $bus_config_json = qq<
 
 [
     {
-        "bus_id"   : "test",
-        "host"     : "localhost",
-        "port"     :  %PORT%,
-        "username" : "test",
-        "password" : "abc123",
+        "bus-id"  : "test",
+        "host"    : "localhost",
+        "user"    : "test",
+        "pass"    : "abc123",
+        "vhost"   : "/test",
+        "default" : 1,
     },
 ]>;
 
@@ -23,16 +24,14 @@ my $toybroker_config_json = qq<
 
 # Mock toybroker.config.json file used by tests
 
-[
-    {
-        "listen_addr" : "127.0.0.1",
-        "listen_port" : %PORT%,
+{
+    "listen_addr" : "127.0.0.1",
+    "listen_port" : "61613",
 
-        "users" : {
-            "test" : { "password" : "abc123" },
-        },
+    "users" : {
+        "test" : { "password" : "abc123" },
     },
-]>;
+}>;
 
 sub read_config_file {
     my ($class, $file) = @_;
@@ -40,10 +39,6 @@ sub read_config_file {
     my $data = $file eq "bus.config.json"       ? $bus_config_json       : 
                $file eq "toybroker.config.json" ? $toybroker_config_json : '';
 
-    #TODO: Find an unused port
-    my $test_port = 51883;
-    $data =~ s/%PORT%/$test_port/;
-
     # Allow comments and end-comma
     my $json = JSON::XS->new->relaxed;
 
